﻿using System.Collections.Generic;
using System.Linq;
using Niche.GroupInspector.Configuration;
using Niche.GroupInspector.Domain;

namespace Niche.GroupInspector.Presentation
{
    /// <summary>
    /// Implementation of IApplicationSystemProvider that loads from the 
    /// applications configuration
    /// </summary>
    public class ConfigurationSystemProvider : IApplicationSystemProvider
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="ConfigurationSystemProvider"/> class.
        /// </summary>
        /// <param name="configuration">Configuration loaded from an external source.</param>
        public ConfigurationSystemProvider(GroupInspectorSettings configuration)
        {
            mConfiguration = configuration;
            mSystems
                = mConfiguration.Systems
                    .Cast<SystemSettings>()
                    .Select(s => CreateApplicationSystem(s))
                    .ToList();
        }

        /// <summary>
        /// Provide all application systems
        /// </summary>
        /// <returns>Sequence of Application Systems</returns>
        public IEnumerable<ApplicationSystem> ProvideApplicationSystems()
        {
            return mSystems;
        }

        private ApplicationSystem CreateApplicationSystem(SystemSettings systemSettings)
        {
            return new ApplicationSystem()
                       {
                           Name = systemSettings.DisplayName,
                           Groups = systemSettings.Groups
                               .Cast<GroupSettings>()
                               .Select(g => CreateGroup(g))
                       };
        }

        private AccessGroup CreateGroup(GroupSettings groupSettings)
        {
            return new AccessGroup()
                       {
                           Name = groupSettings.Name,
                           DisplayName = groupSettings.DisplayName,
                           ActiveDirectoryGroupName = groupSettings.Name
                       };
        }

        private readonly GroupInspectorSettings mConfiguration;

        private List<ApplicationSystem> mSystems = new List<ApplicationSystem>();
    }
}