﻿using System.Collections.Generic;
using Niche.GroupInspector.Domain;

namespace Niche.GroupInspector.Presentation
{
    public class InMemoryGroupModel : IGroupInspectorModel
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="InMemoryGroupModel"/> class.
        /// </summary>
        public InMemoryGroupModel()
        {
            // Nothing
        }

        /// <summary>
        /// Add a new application system, with relevant groups
        /// </summary>
        /// <param name="name">Name of the system we're adding</param>
        /// <param name="groups">Groups of system access</param>
        public void AddSystem(string name, params AccessGroup[] groups)
        {
            var system = new ApplicationSystem()
                             {
                                 Name = name,
                                 Groups = groups
                             };
            mSystems.Add(system);
        }

        /// <summary>
        /// Add a new Access group
        /// </summary>
        /// <param name="group">Group to add</param>
        /// <param name="users">Members of this group</param>
        public void AddGroup(AccessGroup group, params User[] users)
        {
            mMembers.Add(group, users);
        }

        /// <summary>
        /// Load our sequence of available application systems
        /// </summary>
        /// <returns>Sequence of application systems.</returns>
        public IEnumerable<ApplicationSystem> LoadApplicationSystems()
        {
            return mSystems;
        }

        /// <summary>
        /// Get all the users who are a part of the specified access group
        /// </summary>
        /// <param name="accessGroup">Access group for which users are required</param>
        /// <returns>Sequence of found users (possibly empty)</returns>
        public IEnumerable<User> GetUsersForAccessGroup(AccessGroup accessGroup)
        {
            return mMembers[accessGroup];
        }

        private List<ApplicationSystem> mSystems = new List<ApplicationSystem>();

        private Dictionary<AccessGroup,IEnumerable<User>> mMembers 
            = new Dictionary<AccessGroup, IEnumerable<User>>();
    }
}