﻿using System.Collections.Generic;
using Niche.GroupInspector.Domain;

namespace Niche.GroupInspector.Presentation
{
    /// <summary>
    /// An application memory provider that is configured by code.
    /// </summary>
    public class InMemorySystemProvider : IApplicationSystemProvider
    {
        /// <summary>
        /// Add a new system to this provider
        /// </summary>
        /// <param name="name">Name of the system to add</param>
        /// <param name="groups">Groups to include in this system</param>
        public void AddSystem(string name, params AccessGroup[] groups)
        {
            var system = new ApplicationSystem
                             {
                                 Name = name,
                                 Groups = groups
                             };
            mSystems.Add(system);
        }

        /// <summary>
        /// Provide all application systems
        /// </summary>
        /// <returns>Sequence of Application Systems</returns>
        public IEnumerable<ApplicationSystem> ProvideApplicationSystems()
        {
            return mSystems;
        }

        /// <summary>
        /// List of systems known to this provider
        /// </summary>
        private readonly List<ApplicationSystem> mSystems = new List<ApplicationSystem>();
    }
}